@@ -17,7 +17,7 @@ require AutoLoader;
 	new menu format html show
 	
 );
-$VERSION = '0.09';
+$VERSION = '0.02';
 
 $DEBUG=0;
 
@@ -46,19 +46,18 @@ sub format_options {
 				# max number of depth if items are not active
 						  start => '',
 							end => '',
-							font=>'',
+							font=>'<FONT FACE="arial">',
 			  active_item_start => '<B><I>',
 			   	active_item_end => '</B></I>',
 			inactive_item_start => '',
 			  inactive_item_end => '',
-			   text_placeholder => '',
+			   text_placeholder => '<text>',
 							 # example : <IMG SRC="<text>.gif" ALT="<text>">
 							 #				       ------		    ------
 					link_args=>'',
 							# put javascript options here or other args
 							# for the <A HREF tag
 					     indent => 0,
-					    auto_br => 1
 	);
 	my $default_format=$format->{default};
 	foreach (keys %$default_format) {
@@ -87,18 +86,9 @@ sub new {
 	$self->{home}.="/" unless $self->{home}=~m!/$|\.html$!;
 #	print "home=$self->{home}\n";
 	bless ($self,$class);
-	$self->{auth}=$args->{allowed}  if exists $args->{allowed};
 	return $self;
 }
 
-sub call_auth {
-	my $self=shift;
-	return 1 unless exists $self->{auth};
-	my $url=shift;
-	$url=~s!^(\.\./)+!!g;
-	return &{$self->{auth}}( $self->{home}.$url );
-}
-
 sub menu {
 	my $self=shift;
 	my $menu=shift;
@@ -118,43 +108,6 @@ sub home {
 	$self->{home}=$home;
 }
 
-sub title {
-	my $self=shift;
-	my $separator=(shift or '-');
-	my $item;
-	my $title="";
-	foreach (@{$self->active}) {
-		unless (defined $item) {
-			$item=$_;
-			next;
-		}
-		$title.=$separator if length $title;
-		$title.=$item;
-		undef $item;
-	}
-	return $title;
-}
-
-
-sub path {
-	my $self=shift;
-	my $separator=(shift or '/');
-	my $item;
-	my $path="";
-	foreach (@{$self->active}) {
-		unless (defined $item) {
-			$item=$_;
-			next;
-		}
-		$path.=$separator if length $path;
-		$path.="<A HREF=\"$_\">$item</A>";
-		undef $item;
-	}
-	return $path;
-}
-
-
-
 sub show {
 	my $self=shift;
 	my %arg=@_;
@@ -168,31 +121,26 @@ sub html {
 	my $self=shift;
 	$self->set_url();
 	$self->build_active unless defined $self->{active};
-	return $self->{html} if exists $self->{html}
-							&& defined $self->{html};
-	$self->{html}=$self->build_html(@_);
+	my $html=($self->{html} or $self->build_html);
+	$self->{html}=$html;
 	return $self->{html};
 }
 
 sub active {
 	my $self=shift;
-	return $self->{active} if defined $self->{active};
-	$self->set_url;
-	$self->build_active;
+	$self->build_active unless defined $self->{active};
 	return $self->{active};
 }
 
 sub set_url {
 	my $self=shift;
 	return if defined $self->{url} and $self->{url} eq $self->{old_url};
-	croak "Undefined REQUEST_URI" unless defined $ENV{REQUEST_URI};
 	$self->{old_url}=$ENV{REQUEST_URI};
 	delete $self->{html};
 	delete $self->{active};
 	my $home=$self->home;
 	my $url=$ENV{REQUEST_URI};
 	print "url=$url ->" if $DEBUG;
-	$url=~s!/\.$!/!;
 	$url=~s!/+!/!g;
 	$url=~s/$home//; # clean the home part
 	$url=~s/\?.*$//; # and clean the args if any
@@ -200,7 +148,6 @@ sub set_url {
 				or $url=~/\w+:/
 				or $url eq "";
   	$url=~s!//+!/!g;	#strip //
-#	$url.='index.html' if $url=~m!/$!;
 	$self->{path}="";
 	foreach (1 .. $url=~ tr!/!! ) {
 		$self->{path}.="../";
@@ -212,7 +159,6 @@ sub set_url {
 sub build_active {
 	my $self=shift;
 	return if defined $self->{active};
-	print "\nBuilding active for $self->{url}\n" if $DEBUG;
 	$self->recurse_build_active();
 	my $active=$self->{active};
 	my @rev;
@@ -237,7 +183,6 @@ sub recurse_build_active {
 				or $self->{menu}
 				or []);
 	my $path=($arg{path} or $self->{path} or "");
-	print "path=$path\n" if $DEBUG;
 	my $key;
 	my $bActive=0;
 	foreach (@$menu) {
@@ -257,39 +202,23 @@ sub recurse_build_active {
 				die "Unknown key $_\n" unless $_=~/^(url|menu)$/;
 			}
 		}
-		unless (exists $_->{url} and exists $_->{menu}) {
-			undef $key;
-			next;
-		}
-		print "\titem=$_->{url}\n" if $DEBUG;
 		$_->{url}=~s!/$!!;
-		
 		$_->{abs_url}=$_->{url};
 		$_->{abs_url}=$path.$_->{url} unless $_->{url}=~/^\w+:/;
 		$_->{abs_url}.="/" unless $_->{url}=~m!(\.\w+|/)$!
 						or $_->{url}=~/^\w+:/;
-		my $next_path=$path;
-		$next_path.=$_->{url} if $_->{abs_url}=~m!/$!;
-		$next_path.="/" if $_->{abs_url}=~m!/$!;
-
-		$next_path=~s#//+#/#g;
-
-		unless ( $self->call_auth($_->{abs_url}) ){
-			undef $key;
-			next;
-		}
-
+		my $next_path="";
+		$next_path=$_->{abs_url} if $_->{abs_url}=~m!/$!;
 		if ($self->recurse_build_active(menu=>$_->{menu},path=>$next_path) 
 					or $_->{abs_url} eq $self->{url}) {
 			$self->{active_url}->{$_->{abs_url}}++;
 			my $active=$self->{active};
-			push @$active,($key,$_->{abs_url}) ;
+			push @$active,($key,$_->{abs_url});
 			$self->{active}=$active;
 			$_->{active}++;
 			$bActive=1;
 		}
-#		$_->{abs_url}.="index.html" if $_->{abs_url}=~m!/$!;
-		print "\turl=".$_->{abs_url} if $DEBUG;
+		print $_->{abs_url} if $DEBUG;
 		print "*" if $DEBUG and $bActive;;
 		print "\n" if $DEBUG;
 		undef $key;
@@ -310,17 +239,18 @@ sub build_html {
 	my $indent=0;
 	$indent= $arg->{indent} if exists $arg->{indent};
 
+
 	my $url=$self->{abs_url};
 
 	my $format=format_options(($arg->{format} or $self->{format}),$level);
 	$indent+=$format->{indent};
 	my $width=0;
-	($width)=$format->{active_item_start}=~/WIDTH=\"?(\d+)/i 
-		if exists $format->{active_item_start};
-	$width=0 unless defined $width;
+	($width)=$format->{active_item_start}=~/WIDTH=(\d+)/i;
+
 	my $ret="";
 	my $key;
 	
+	$ret.=$format->{font};
 
 	foreach (@$rMenu) {
 		$ret.=$format->{start};
@@ -328,38 +258,28 @@ sub build_html {
         	$key=$_;
         	next;
     	}
-		unless ( exists $_->{menu} ) {
-			undef $key;
-			next;
-		}
     	my $sub_menu=$_->{menu};
 		my $bActive=$_->{active};
     	if ($bActive) {
-			$ret.=$format->{active_item_start};
 	    	$ret.="<IMG SRC='/img/point.gif' WIDTH=$indent HEIGHT=3>"  
-				if $indent;
+				if ($indent);
+		    $ret.=$format->{active_item_start};
     	} else {
 	    	$ret.=$format->{inactive_item_start};
-	    	$ret.="<IMG SRC=\"/img/point.gif\" WIDTH=".($indent+$width)." HEIGHT=1>"  if $indent+$width;
+	    	$ret.="<IMG SRC='/img/point.gif' WIDTH=".($indent+$width)." HEIGHT=1>"  if $indent+$width;
     	}
 		if (length $_->{abs_url}) {
 			my $link_w="<A HREF=\"".$_->{abs_url}."\" $format->{link_args}>";
 			$link_w=~s/\<text\>/$key/g;
 			$ret.=$link_w;
 		}
-		$ret.=$format->{font} 
-			if exists $format->{font} and length $format->{font};
-
-		if (defined $format->{text_placeholder} 
-					and length $format->{text_placeholder}) {
+		if (defined $format->{text_placeholder}) {
 			my $wrap=$format->{text_placeholder};
 			$wrap=~s/\<text\>/$key/g;
     		$ret.=$wrap;
 		} else {
 			$ret.=$key;
 		}
-		$ret.="</FONT>" if exists $format->{font} and length $format->{font};
-
     	$ret.="</A>";
 
     	if ($bActive and length $_->{url}) {
@@ -367,10 +287,7 @@ sub build_html {
     	} else {
 	    	$ret.=$format->{inactive_item_end};
     	}
-    	$ret.="<BR>" unless (defined $format->{text_placeholder}
-								&& length $format->{text_placeholder})
-						|| !$format->{auto_br};
-		$ret.="\n";
+    	$ret.="<BR>\n";
     	if ($level<$format->{max_depth} or $bActive) {
 	  		my $subMenu	=$self->build_html(
 					menu=>$sub_menu,
@@ -383,6 +300,7 @@ sub build_html {
     	undef $key;
     	$ret.=$format->{end};
 	}
+	$ret.="</FONT>";
 	return $ret;
 }
 
@@ -418,22 +336,12 @@ HTML::Widgets::Menu - Builds an HTML menu
             },
             item2=>"url for item 2"
             # more items
-         ],
-		
-         # this is experimental
-
-         allowed => sub {
-             my ($url)=shift;
-             my $user=$r->connection->user();
-			return 1 unless defined $user;
-			return ($user eq "frankie"  && $url =~/^intranet/);
-         }
+         ]
       );
 
+      my ($menu)=$main->show();
 
-	print "<h1>$menu->title</h1>",
-	print "<h2>$menu->path</h2>",
-    print $menu->html;
+      <% $menu %>
 
 =head1 DESCRIPTION
 
@@ -444,7 +352,7 @@ It's smart enough it will highlight the current active items.
 
 You can see an example of this here: http://www.etsetb.upc.es/~frankie
 
-This software is more mature that latest version. It works fine for me and
+This software is in a very early stage. It works fine for me and
 is used in production sites. The very first version was almost unusable
 if you didn't had very strict rules for creating the menu, now it's
 much improved and useful. Tell me if you like it or not.
@@ -472,12 +380,12 @@ For example, a simple menu could be:
           "my links" =>"links.html"
     );
 
-You can add depth to the menu:
+You can add levels of depth to the menu:
 
 
     my @menu=(  
-        homepage   => '.',
-        "my links" => {
+        homepage => '.',
+        "my links=>{
                   url=>"links/",
                   menu=>[
                         perl  =>"perl_link.html",
@@ -487,7 +395,7 @@ You can add depth to the menu:
      );
 
 For every level you add instead of the url you must supply a
-reference to a hash with the url and the submenu.
+reference to a hash with the url and the menu.
 Now you can get this menu printed in html easily and get the
 list of active items.
 
@@ -529,11 +437,9 @@ Options available (with defaults):
   link_args=>'',
            # put javascript options here or other args
            # for the <A HREF tag
-  indent => 8,
+  indent => 1,
 			# pixels for the indentation
 
-  auto_br => 1, # Adds a <br> at the end of every line [default 1]
-
 Example:
 my %format={
    default=>{
@@ -567,91 +473,32 @@ must call the html method. It will build it using home,
 format and menu. The final links will always be related
 to the current URL. 
 
-
-The pixel indentation is done using the url /img/point.gif.
-
-If you define an active format with an image like this:
-    active_item_start=> ' <IMG SRC="arrow.gif" WIDTH="10">'
-
-this WIDTH is added to the indentation so it looks pretty cool
-in the screen:
-
-
-       not active
-       another url
-    => this is the active
-       another one
-
-			
-The other items have been indented the width of the image, in addition
-to the indent tag in the format.
-
-
-The activation of the items work automagically reading the environment 
-variable provided by the web server: $ENV{REQUEST_URI}
-
-=head2 Active Items
-
 The active method returns a usefull thing: the active
 items of the menu. In the former example if the user is in
 the url:  "movies.html" it will return a reference to a list
 like this:
 	"my_links"=>"links"
 	"movies I like "=>"links/movies.html"
+so you can know the path of the currem item. Now you can add the
+keys of it to the title for example.
 
-What can I do with the active items ?
+The pixel indentation is done using the url /img/point.gif.
 
-once the menu is built you can retrieve its active items this way:
-
-	$menu->active;
-
-This method returns an array with the items and links this way:
-
-	item1 , link1 , item2, link2
-
-You can use it to build a title or path like this: 
-
-	print $menu->html; # that builds the menu
+If you define an active format with an image like this:
+	active_item_start=> ' <IMG SRC="arrow.gif" WIDTH="10">'
+this WIDTH is added to the indentation so it looks pretty cool
+in the screen:
+	   not active
+	   another url
+	=> this is the active
+	   another
+			
+The others have been indented the width of the image, in addition
+to the indent tag in the format.
 
 
-	my $title="Main Title";
-	my $path="";
-	my $item;
-	foreach (@{$menu->active}) {
-		$item=$_ and next unless defined $item;
-
-		$title.=" - $item";
-
-		$path.="/" if length $path;
-		$path.="<A HREF=\"$_\">$item</A>";
-
-		undef $item;
-
-	}
-	# now I have a title and path variables
-
-
-=head2 Experimental Features
-
-=over
-
-=item *
-
-see test.pl file for a cool feature that lets you read menu
-data from a database !
-
-=item *
-
-There is another new feature that lets you do authorization. So you
-can have some users access some menus and other don't.
-
-=back
-
-
-=head2 PLEASE
-
-	Please, tell me you're using it. I'll accept requests, comments,
-	suggestions, bug patches.
+The activation of the items work reading the environment variable
+provided by the web server: $ENV{REQUEST_URI}
 
 
 =head1 AUTHOR
